#!/usr/bin/env python
# -*- coding: utf-8 -*-

from typing import List

import bioio_base.reader_metadata

###############################################################################


class ReaderMetadata(bioio_base.reader_metadata.ReaderMetadata):
    """
    Notes
    -----
    Defines metadata for the reader itself (not the image read),
    such as supported file extensions.
    """

    @staticmethod
    def get_supported_extensions() -> List[str]:
        """
        Return a list of file extensions this plugin supports reading.
        """
        return [
            ".1sc",
            ".2fl",
            ".acff",
            ".afi",
            ".afm",
            ".aim",
            ".al3d",
            ".am",
            ".amiramesh",
            ".apl",
            ".arf",
            ".avi",
            ".bin",
            ".bip",
            ".bmp",
            ".btf",
            ".c01",
            ".cfg",
            ".ch5",
            ".cif",
            ".cr2",
            ".crw",
            ".csv",
            ".cxd",
            ".czi",
            ".dat",
            ".dcm",
            ".dib",
            ".dm2",
            ".dm3",
            ".dm4",
            ".dti",
            ".dv",
            ".eps ",
            ".exp",
            ".fdf",
            ".fff",
            ".ffr",
            ".fits",
            ".flex",
            ".fli",
            ".frm",
            ".gel",
            ".gif",
            ".grey",
            ".hdf",
            ".hdr",
            ".hed",
            ".his",
            ".htd",
            ".html",
            ".hx",
            ".i2i",
            ".ics",
            ".ids",
            ".im3",
            ".img",
            ".ims",
            ".inr",
            ".ipl",
            ".ipm",
            ".ipw",
            ".jp2",
            ".jpg",
            ".jpk",
            ".jpx",
            ".l2d",
            ".labels",
            ".lei",
            ".lif",
            ".liff",
            ".lim",
            ".lms",
            ".lsm",
            ".mdb",
            ".mnc",
            ".mng",
            ".mod",
            ".mov",
            ".mrc",
            ".mrw",
            ".msr",
            ".mtb",
            ".mvd2",
            ".naf",
            ".nd",
            ".nd2",
            ".ndpi",
            ".ndpis",
            ".nef",
            ".nhdr",
            ".nii",
            ".nii.gz",
            ".nrrd",
            ".obf",
            ".obsep",
            ".oib",
            ".oif",
            ".oir",
            ".ome",
            ".ome.btf",
            ".ome.tf2",
            ".ome.tf8",
            ".ome.tif",
            ".ome.tiff",
            ".ome.xml",
            ".par",
            ".pbm",
            ".pcoraw",
            ".pcx",
            ".pds",
            ".pgm",
            ".pic",
            ".pict",
            ".png",
            ".pnl",
            ".ppm",
            ".pr3",
            ".psd",
            ".qptiff",
            ".r3d",
            ".raw",
            ".rec",
            ".scn",
            ".sdt",
            ".seq",
            ".sif",
            ".sld",
            ".sm2",
            ".sm3",
            ".spc",
            ".spe",
            ".spi",
            ".stk",
            ".stp",
            ".svs",
            ".sxm",
            ".tf2",
            ".tf8",
            ".tfr",
            ".tga",
            ".tif",
            ".tiff",
            ".tnb",
            ".top",
            ".txt",
            ".v",
            ".vms",
            ".vsi",
            ".vws",
            ".wat",
            ".wlz",
            ".xdce",
            ".xml",
            ".xqd",
            ".xqf",
            ".xv",
            ".xys",
            ".zfp",
            ".zfr",
            ".zvi",
        ]

    @staticmethod
    def get_reader() -> bioio_base.reader.Reader:
        """
        Return the reader this plugin represents
        """
        from .reader import Reader

        return Reader
